# Cosmos DB API for MongoDB TypeScript Quickstart

## Setup the Project

First, clone or download the project from this repository.

### Provision a Cosmos DB API for MongoDB account

Follow [these instructions](https://docs.microsoft.com/en-us/azure/cosmos-db/create-mongodb-dotnet#create-a-database-account) to create a database account.

Once you have created an account create a collection with the following configuration.

![create collection](./images/create-collection.png)

> Note: ensure Sku is capitalized when entering your shard key.

### Update secrets

Rename the `sample.env` file to `.env`. Enter your connection string and modify the database and collection names if you created them with different names.

Find your connection string by selecting your Cosmos DB account in the Azure portal. Click Connection String in the left navigation, and then click Read-write Keys. Use the copy buttons on the right side of the screen to copy the Primary Connection String.

```json
COSMOSDB_CONNECTIONSTRING=
DATABASE_NAME=cosmicworks
PRODUCTS_COLLECTION_NAME=products
```

### Load sample data

Use [mongoimport](https://docs.mongodb.com/database-tools/mongoimport/#mongodb-binary-bin.mongoimport) to load the sample products provided in the `Data` folder of this repository. Mongoimport is a command line tool that allows you to easily import small amounts of JSON, CSV or TSV data. [Download](https://www.mongodb.com/try/download/database-tools) the tool and run the following from the root of this repository to load the sample data. Update the host, port, username, and password with values from the Connection String left navigation blade in the Azure portal. Be sure to also update the database and collection names if you named yours differently.

```cmd
mongoimport --host <HOST>:<PORT> -u <USERNAME> -p <PASSWORD> --db cosmicworks --collection products --ssl --jsonArray --writeConcern="{w:0}" --file data/products.json
```

> Note: If you would like to skip this step you can create documents with the correct schema via the POST endpoint provided in this project.

## Run the Project

Enter the following at the command line from the root directory of the project.

```cmd
npm start
```

After the application is running, navigate to [http://localhost:3000/api-docs](http://localhost:3000/api-docs) to see the swagger documentation for the web api and to submit sample requests.

Click on the API you would like to test and select "Try it out".

![try-swagger](./images/swagger-1.png)

Enter any necessary parameters and select "Execute."

![execute-swagger](./images/swagger-2.png)
