import { Product } from "./product";
import { Schema, model } from "mongoose";
import dotenv from "dotenv";

dotenv.config();

const schema = new Schema<Product>(
  {
    CategoryName: { type: String, required: true },
    Sku: { type: String, required: true },
    Name: { type: String, required: true },
    Description: { type: String, required: true },
    Price: { type: Number, required: true },
  },
  {
    versionKey: false,
  }
);

let collection = process.env.PRODUCTS_COLLECTION_NAME;
if (collection == undefined) {
  collection = "products";
}
const ProductModel = model<Product>(collection, schema);

export class ProductService {
  getN(n: number): Promise<Product[]> {
    return ProductModel.find({}).limit(n).exec();
  }

  getBySku(Sku: string): Promise<Product | null> {
    return ProductModel.findOne({ Sku }).exec();
  }

  async create(product: Product): Promise<void> {
    const doc = new ProductModel({
      ...product,
    });

    await doc.save();
  }

  update(product: Product): Promise<Product | null> {
    return ProductModel.findOneAndReplace({ Sku: product.Sku }, product, {
      returnDocument: "after",
    }).exec();
  }

  async delete(Sku: string): Promise<void> {
    await ProductModel.deleteOne({ Sku }).exec();
  }
}
